@@ -645,7 +645,7 @@ static int __init init_ibmtr_cs(void)
     if (serv.Revision != CS_RELEASE_CODE) {
         printk(KERN_NOTICE "ibmtr_cs: Card Services release "
 	       "does not match!\n");
-        return -1;
+        return -EINVAL;
     }
     register_pccard_driver(&dev_info, &ibmtr_attach, &ibmtr_detach);
     return 0;
