@@ -1593,7 +1593,7 @@ static int __init init_netwave_cs(void) {
     CardServices(GetCardServicesInfo, &serv);
     if (serv.Revision != CS_RELEASE_CODE) {
 	printk("netwave_cs: Card Services release does not match!\n");
-	return -1;
+	return -EINVAL;
     }
  
     register_pccard_driver(&dev_info, &netwave_attach, &netwave_detach);
